diff --git a/alluxio/src/main/resources/interpreter-setting.json b/alluxio/src/main/resources/interpreter-setting.json
index f73aae4b9c..cf0101befb 100644
--- a/alluxio/src/main/resources/interpreter-setting.json
+++ b/alluxio/src/main/resources/interpreter-setting.json
@@ -9,14 +9,14 @@
"propertyName": "alluxio.master.hostname",
"defaultValue": "localhost",
"description": "Alluxio master hostname",
- "type": "text"
+ "widget": "string"
},
"alluxio.master.port": {
"envName": "ALLUXIO_MASTER_PORT",
"propertyName": "alluxio.master.port",
"defaultValue": "19998",
"description": "Alluxio master port",
- "type": "text"
+ "widget": "number"
}
},
"editor": {
diff --git a/beam/src/main/resources/interpreter-setting.json b/beam/src/main/resources/interpreter-setting.json
index b6d5559fd6..b715a2114b 100644
--- a/beam/src/main/resources/interpreter-setting.json
+++ b/beam/src/main/resources/interpreter-setting.json
@@ -20,14 +20,14 @@
"propertyName": "zeppelin.scio.argz",
"defaultValue": "--runner=InProcessPipelineRunner",
"description": "Scio interpreter wide arguments",
- "type": "text"
+ "widget": "text"
},
"zeppelin.scio.maxResult": {
"envName": "ZEPPELIN_SCIO_MAXRESULT",
"propertyName": "zeppelin.scio.maxResult",
"defaultValue": "1000",
"description": "Max number of SCollection results to display.",
- "type": "text"
+ "widget": "number"
}
},
"editor": {
diff --git a/bigquery/src/main/resources/interpreter-setting.json b/bigquery/src/main/resources/interpreter-setting.json
index fbe0874de2..1d0c516f87 100644
--- a/bigquery/src/main/resources/interpreter-setting.json
+++ b/bigquery/src/main/resources/interpreter-setting.json
@@ -9,21 +9,21 @@
"propertyName": "zeppelin.bigquery.project_id",
"defaultValue": " ",
"description": "Google Project ID",
- "type": "text"
+ "widget": "string"
},
"zeppelin.bigquery.wait_time": {
"envName": null,
"propertyName": "zeppelin.bigquery.wait_time",
"defaultValue": "5000",
"description": "Query timeout in Milliseconds",
- "type": "text"
+ "widget": "number"
},
"zeppelin.bigquery.max_no_of_rows": {
"envName": null,
"propertyName": "zeppelin.bigquery.max_no_of_rows",
"defaultValue": "100000",
"description": "Maximum number of rows to fetch from BigQuery",
- "type": "text"
+ "widget": "number"
}
},
"editor": {
diff --git a/cassandra/src/main/resources/interpreter-setting.json b/cassandra/src/main/resources/interpreter-setting.json
index 71ad4e4e5e..cb90121793 100644
--- a/cassandra/src/main/resources/interpreter-setting.json
+++ b/cassandra/src/main/resources/interpreter-setting.json
@@ -9,217 +9,217 @@
"propertyName": "cassandra.hosts",
"defaultValue": "localhost",
"description": "Comma separated Cassandra hosts (DNS name or IP address). Default = localhost. Ex: '192.168.0.12,node2,node3'",
- "type": "text"
+ "widget": "text"
},
"cassandra.native.port": {
"envName": null,
"propertyName": "cassandra.native.port",
"defaultValue": "9042",
"description": "Cassandra native port. Default = 9042",
- "type": "text"
+ "widget": "number"
},
"cassandra.protocol.version": {
"envName": null,
"propertyName": "cassandra.protocol.version",
"defaultValue": "4",
"description": "Cassandra protocol version. Default = 4",
- "type": "text"
+ "widget": "string"
},
"cassandra.cluster": {
"envName": null,
"propertyName": "cassandra.cluster",
"defaultValue": "Test Cluster",
"description": "Cassandra cluster name. Default = 'Test Cluster'",
- "type": "text"
+ "widget": "string"
},
"cassandra.keyspace": {
"envName": null,
"propertyName": "cassandra.keyspace",
"defaultValue": "system",
"description": "Cassandra keyspace name. Default = 'system'",
- "type": "text"
+ "widget": "string"
},
"cassandra.compression.protocol": {
"envName": null,
"propertyName": "cassandra.compression.protocol",
"defaultValue": "NONE",
"description": "Cassandra compression protocol. Available values: NONE, SNAPPY, LZ4. Default = NONE",
- "type": "text"
+ "widget": "string"
},
"cassandra.credentials.username": {
"envName": null,
"propertyName": "cassandra.credentials.username",
"defaultValue": "none",
"description": "Cassandra credentials username. Default = 'none'",
- "type": "text"
+ "widget": "string"
},
"cassandra.credentials.password": {
"envName": null,
"propertyName": "cassandra.credentials.password",
"defaultValue": "none",
"description": "Cassandra credentials password. Default = 'none'",
- "type": "password"
+ "widget": "password"
},
"cassandra.load.balancing.policy": {
"envName": null,
"propertyName": "cassandra.load.balancing.policy",
"defaultValue": "DEFAULT",
"description": "Cassandra Load Balancing Policy. Default = new TokenAwarePolicy(new DCAwareRoundRobinPolicy())",
- "type": "text"
+ "widget": "string"
},
"cassandra.retry.policy": {
"envName": null,
"propertyName": "cassandra.retry.policy",
"defaultValue": "DEFAULT",
"description": "Cassandra Retry Policy. Default = DefaultRetryPolicy.INSTANCE",
- "type": "text"
+ "widget": "string"
},
"cassandra.reconnection.policy": {
"envName": null,
"propertyName": "cassandra.reconnection.policy",
"defaultValue": "DEFAULT",
"description": "Cassandra Reconnection Policy. Default = new ExponentialReconnectionPolicy(1000, 10 * 60 * 1000)",
- "type": "text"
+ "widget": "string"
},
"cassandra.speculative.execution.policy": {
"envName": null,
"propertyName": "cassandra.speculative.execution.policy",
"defaultValue": "DEFAULT",
"description": "Cassandra Speculative Execution Policy. Default = NoSpeculativeExecutionPolicy.INSTANCE",
- "type": "text"
+ "widget": "string"
},
"cassandra.interpreter.parallelism": {
"envName": null,
"propertyName": "cassandra.interpreter.parallelism",
"defaultValue": "10",
"description": "Cassandra interpreter parallelism.Default = 10",
- "type": "text"
+ "widget": "number"
},
"cassandra.max.schema.agreement.wait.second": {
"envName": null,
"propertyName": "cassandra.max.schema.agreement.wait.second",
"defaultValue": "10",
"description": "Cassandra max schema agreement wait in second.Default = ProtocolOptions.DEFAULT_MAX_SCHEMA_AGREEMENT_WAIT_SECONDS",
- "type": "text"
+ "widget": "number"
},
"cassandra.pooling.new.connection.threshold.local": {
"envName": null,
"propertyName": "cassandra.pooling.new.connection.threshold.local",
"defaultValue": "100",
"description": "Cassandra new connection threshold local. Protocol V2 and below default = 100 Protocol V3 and above default = 800",
- "type": "text"
+ "widget": "number"
},
"cassandra.pooling.new.connection.threshold.remote": {
"envName": null,
"propertyName": "cassandra.pooling.new.connection.threshold.remote",
"defaultValue": "100",
"description": "Cassandra new connection threshold remove. Protocol V2 and below default = 100 Protocol V3 and above default = 200",
- "type": "text"
+ "widget": "number"
},
"cassandra.pooling.core.connection.per.host.local": {
"envName": null,
"propertyName": "cassandra.pooling.core.connection.per.host.local",
"defaultValue": "2",
"description": "Cassandra core connection per host local. Protocol V2 and below default = 2 Protocol V3 and above default = 1",
- "type": "text"
+ "widget": "number"
},
"cassandra.pooling.core.connection.per.host.remote": {
"envName": null,
"propertyName": "cassandra.pooling.core.connection.per.host.remote",
"defaultValue": "1",
"description": "Cassandra core connection per host remove. Protocol V2 and below default = 1 Protocol V3 and above default = 1",
- "type": "text"
+ "widget": "number"
},
"cassandra.pooling.max.connection.per.host.local": {
"envName": null,
"propertyName": "cassandra.pooling.max.connection.per.host.local",
"defaultValue": "8",
"description": "Cassandra max connection per host local. Protocol V2 and below default = 8 Protocol V3 and above default = 1",
- "type": "text"
+ "widget": "number"
},
"cassandra.pooling.max.connection.per.host.remote": {
"envName": null,
"propertyName": "cassandra.pooling.max.connection.per.host.remote",
"defaultValue": "2",
"description": "Cassandra max connection per host remote. Protocol V2 and below default = 2 Protocol V3 and above default = 1",
- "type": "text"
+ "widget": "number"
},
"cassandra.pooling.max.request.per.connection.local": {
"envName": null,
"propertyName": "cassandra.pooling.max.request.per.connection.local",
"defaultValue": "1024",
"description": "Cassandra max request per connection local. Protocol V2 and below default = 128 Protocol V3 and above default = 1024",
- "type": "text"
+ "widget": "number"
},
"cassandra.pooling.max.request.per.connection.remote": {
"envName": null,
"propertyName": "cassandra.pooling.max.request.per.connection.remote",
"defaultValue": "256",
"description": "Cassandra max request per connection remote. Protocol V2 and below default = 128 Protocol V3 and above default = 256",
- "type": "text"
+ "widget": "number"
},
"cassandra.pooling.idle.timeout.seconds": {
"envName": null,
"propertyName": "cassandra.pooling.idle.timeout.seconds",
"defaultValue": "120",
"description": "Cassandra idle time out in seconds. Default = 120",
- "type": "text"
+ "widget": "number"
},
"cassandra.pooling.pool.timeout.millisecs": {
"envName": null,
"propertyName": "cassandra.pooling.pool.timeout.millisecs",
"defaultValue": "5000",
"description": "Cassandra pool time out in millisecs. Default = 5000",
- "type": "text"
+ "widget": "number"
},
"cassandra.pooling.heartbeat.interval.seconds": {
"envName": null,
"propertyName": "cassandra.pooling.heartbeat.interval.seconds",
"defaultValue": "30",
"description": "Cassandra pool heartbeat interval in secs. Default = 30",
- "type": "text"
+ "widget": "number"
},
"cassandra.query.default.consistency": {
"envName": null,
"propertyName": "cassandra.query.default.consistency",
"defaultValue": "ONE",
"description": "Cassandra query default consistency level. Default = ONE",
- "type": "text"
+ "widget": "string"
},
"cassandra.query.default.serial.consistency": {
"envName": null,
"propertyName": "cassandra.query.default.serial.consistency",
"defaultValue": "SERIAL",
"description": "Cassandra query default serial consistency level. Default = SERIAL",
- "type": "text"
+ "widget": "string"
},
"cassandra.query.default.fetchSize": {
"envName": null,
"propertyName": "cassandra.query.default.fetchSize",
"defaultValue": "5000",
"description": "Cassandra query default fetch size. Default = 5000",
- "type": "text"
+ "widget": "number"
},
"cassandra.socket.connection.timeout.millisecs": {
"envName": null,
"propertyName": "cassandra.socket.connection.timeout.millisecs",
"defaultValue": "5000",
"description": "Cassandra socket default connection timeout in millisecs. Default = 5000",
- "type": "text"
+ "widget": "number"
},
"cassandra.socket.read.timeout.millisecs": {
"envName": null,
"propertyName": "cassandra.socket.read.timeout.millisecs",
"defaultValue": "12000",
"description": "Cassandra socket read timeout in millisecs. Default = 12000",
- "type": "text"
+ "widget": "number"
},
"cassandra.socket.tcp.no_delay": {
"envName": null,
"propertyName": "cassandra.socket.tcp.no_delay",
"defaultValue": true,
"description": "Cassandra socket TCP no delay. Default = true",
- "type": "checkbox"
+ "widget": "checkbox"
}
},
"editor": {
diff --git a/docs/development/writingzeppelininterpreter.md b/docs/development/writingzeppelininterpreter.md
index e106461a30..87f2b84f3d 100644
--- a/docs/development/writingzeppelininterpreter.md
+++ b/docs/development/writingzeppelininterpreter.md
@@ -62,14 +62,14 @@ Here is an example of `interpreter-setting.json` on your own interpreter.
"propertyName": "property.1.name",
"defaultValue": "propertyDefaultValue",
"description": "Property description",
- "type": "text"
+ "widget": "text"
},
"properties2": {
"envName": PROPERTIES_2,
"propertyName": null,
"defaultValue": "property2DefaultValue",
"description": "Property 2 description",
- "type": "text"
+ "widget": "text"
}, ...
},
"editor": {
diff --git a/docs/install/upgrade.md b/docs/install/upgrade.md
index 5022123091..4ae047a2c0 100644
--- a/docs/install/upgrade.md
+++ b/docs/install/upgrade.md
@@ -87,12 +87,12 @@ So, copying `notebook` and `conf` directory should be enough.
"spark.executor.memory": {
"name": "spark.executor.memory",
"value": "",
- "type": "text"
+ "widget": "text"
},
"zeppelin.spark.concurrentSQL": {
"name": "zeppelin.spark.concurrentSQL",
"value": false,
- "type": "checkbox"
+ "widget": "checkbox"
...
}
```
\ No newline at end of file
diff --git a/docs/rest-api/rest-interpreter.md b/docs/rest-api/rest-interpreter.md
index a38f8fbcaf..3a64b8aece 100644
--- a/docs/rest-api/rest-interpreter.md
+++ b/docs/rest-api/rest-interpreter.md
@@ -77,12 +77,12 @@ The role of registered interpreters, settings and interpreters group are describ
"spark.executor.memory": {
"defaultValue": "1g",
"description": "Executor memory per worker instance. ex) 512m, 32g",
- "type": "text
+ "widget": "text
},
"spark.cores.max": {
"defaultValue": "",
"description": "Total number of cores to use. Empty value uses all available core.",
- "type": "text"
+ "widget": "text"
},
},
"path": "/zeppelin/interpreter/spark"
@@ -95,7 +95,7 @@ The role of registered interpreters, settings and interpreters group are describ
"zeppelin.spark.maxResult": {
"defaultValue": "1000",
"description": "Max number of Spark SQL result to display.",
- "type": "text"
+ "widget": "text"
}
},
"path": "/zeppelin/interpreter/spark"
@@ -157,14 +157,14 @@ The role of registered interpreters, settings and interpreters group are describ
"group": "spark",
"properties": {
"spark.cores.max": {
- name: "",
- value: "spark.cores.max",
- type: "text"
+ "name": "",
+ "value": "spark.cores.max",
+ "widget": "text"
},
"spark.executor.memory": {
"name": "",
"value": "1g",
- "type": "text"
+ "widget": "text"
}
},
"interpreterGroup": [
@@ -229,7 +229,7 @@ The role of registered interpreters, settings and interpreters group are describ
"propname": {
"name": "propname",
"value": "propvalue",
- "type": "text"
+ "widget": "text"
}
},
"interpreterGroup": [
@@ -288,7 +288,7 @@ The role of registered interpreters, settings and interpreters group are describ
"propname": {
"name": "propname",
"value": "propvalue",
- "type": "text"
+ "widget": "text"
},
"interpreterGroup": [
{
@@ -323,7 +323,7 @@ The role of registered interpreters, settings and interpreters group are describ
"propname": {
"name": "propname",
"value": "propvalue",
- "type": "text"
+ "widget": "text"
},
"interpreterGroup": [
{
@@ -377,7 +377,7 @@ The role of registered interpreters, settings and interpreters group are describ
"propname": {
"name": "propname",
"value": "Otherpropvalue",
- "type": "text"
+ "widget": "text"
},
"interpreterGroup": [
{
@@ -412,7 +412,7 @@ The role of registered interpreters, settings and interpreters group are describ
"propname": {
"name": "propname",
"value": "Otherpropvalue",
- "type": "text"
+ "widget": "text"
},
"interpreterGroup": [
{
@@ -569,16 +569,16 @@ The role of registered interpreters, settings and interpreters group are describ
-### Get available types for property
+### Get available widgets for property
| Description |
- This ```GET``` method returns available types for interpreter property. |
+ This ```GET``` method returns available widgets for interpreter property. |
| URL |
- ```http://[zeppelin-server]:[zeppelin-port]/api/interpreter/property/types``` |
+ ```http://[zeppelin-server]:[zeppelin-port]/api/interpreter/property/widgets``` |
| Success code |
diff --git a/elasticsearch/src/main/resources/interpreter-setting.json b/elasticsearch/src/main/resources/interpreter-setting.json
index af471d9f3d..a053022436 100644
--- a/elasticsearch/src/main/resources/interpreter-setting.json
+++ b/elasticsearch/src/main/resources/interpreter-setting.json
@@ -9,48 +9,49 @@
"propertyName": "elasticsearch.host",
"defaultValue": "localhost",
"description": "The host for Elasticsearch",
- "type": "text"
+ "widget": "string"
},
"elasticsearch.port": {
"envName": "ELASTICSEARCH_PORT",
"propertyName": "elasticsearch.port",
"defaultValue": "9300",
"description": "The port for Elasticsearch",
- "type": "text"
+ "widget": "number"
},
"elasticsearch.client.type": {
"envName": "ELASTICSEARCH_CLIENT_TYPE",
"propertyName": "elasticsearch.client.type",
"defaultValue": "transport",
"description": "The type of client for Elasticsearch (transport or http)",
- "type": "text"
+ "widget": "string"
},
"elasticsearch.cluster.name": {
"envName": "ELASTICSEARCH_CLUSTER_NAME",
"propertyName": "elasticsearch.cluster.name",
"defaultValue": "elasticsearch",
"description": "The cluster name for Elasticsearch",
- "type": "text"
+ "widget": "string"
},
"elasticsearch.result.size": {
"envName": "ELASTICSEARCH_RESULT_SIZE",
"propertyName": "elasticsearch.result.size",
"defaultValue": "10",
"description": "The size of the result set of a search query",
- "type": "text"
+ "widget": "number"
},
"elasticsearch.basicauth.username": {
"envName": "ELASTICSEARCH_BASIC_AUTH_USERNAME",
"propertyName": "elasticsearch.basicauth.username",
"defaultValue": "",
- "description": "Username for a basic authentication"
+ "description": "Username for a basic authentication",
+ "widget": "string"
},
"elasticsearch.basicauth.password": {
"envName": "ELASTICSEARCH_BASIC_AUTH_PASSWORD",
"propertyName": "elasticsearch.basicauth.password",
"defaultValue": "",
"description": "Password for a basic authentication",
- "type": "password"
+ "widget": "password"
}
},
"editor": {
diff --git a/file/src/main/resources/interpreter-setting.json b/file/src/main/resources/interpreter-setting.json
index 0560e749d8..f30bdc6fbc 100644
--- a/file/src/main/resources/interpreter-setting.json
+++ b/file/src/main/resources/interpreter-setting.json
@@ -9,21 +9,21 @@
"propertyName": "hdfs.url",
"defaultValue": "http://localhost:50070/webhdfs/v1/",
"description": "The URL for WebHDFS",
- "type": "text"
+ "widget": "url"
},
"hdfs.user": {
"envName": null,
"propertyName": "hdfs.user",
"defaultValue": "hdfs",
"description": "The WebHDFS user",
- "type": "text"
+ "widget": "string"
},
"hdfs.maxlength": {
"envName": null,
"propertyName": "hdfs.maxlength",
"defaultValue": "1000",
"description": "Maximum number of lines of results fetched",
- "type": "text"
+ "widget": "number"
}
},
"editor": {
diff --git a/flink/src/main/resources/interpreter-setting.json b/flink/src/main/resources/interpreter-setting.json
index 395ef7f828..ca98af826f 100644
--- a/flink/src/main/resources/interpreter-setting.json
+++ b/flink/src/main/resources/interpreter-setting.json
@@ -9,14 +9,14 @@
"propertyName": null,
"defaultValue": "local",
"description": "host name of running JobManager. 'local' runs flink in local mode.",
- "type": "text"
+ "widget": "string"
},
"port": {
"envName": "port",
"propertyName": null,
"defaultValue": "6123",
"description": "port of running JobManager.",
- "type": "text"
+ "widget": "number"
}
},
"editor": {
diff --git a/geode/src/main/resources/interpreter-setting.json b/geode/src/main/resources/interpreter-setting.json
index 5f0e79c63b..94031bb56a 100644
--- a/geode/src/main/resources/interpreter-setting.json
+++ b/geode/src/main/resources/interpreter-setting.json
@@ -9,21 +9,21 @@
"propertyName": "geode.locator.host",
"defaultValue": "localhost",
"description": "The Geode Locator Host.",
- "type": "text"
+ "widget": "string"
},
"geode.locator.port": {
"envName": null,
"propertyName": "geode.locator.port",
"defaultValue": "10334",
"description": "The Geode Locator Port.",
- "type": "text"
+ "widget": "number"
},
"geode.max.result": {
"envName": null,
"propertyName": "geode.max.result",
"defaultValue": "1000",
"description": "Max number of OQL result to display.",
- "type": "text"
+ "widget": "number"
}
},
"editor": {
diff --git a/groovy/src/main/resources/interpreter-setting.json b/groovy/src/main/resources/interpreter-setting.json
index 92e94c9487..e9d200e142 100644
--- a/groovy/src/main/resources/interpreter-setting.json
+++ b/groovy/src/main/resources/interpreter-setting.json
@@ -9,7 +9,7 @@
"propertyName": "GROOVY_CLASSES",
"defaultValue": "",
"description": "The path for custom groovy classes location. If empty `./interpreter/groovy/classes`",
- "type": "text"
+ "widget": "text"
}
}
}
diff --git a/hbase/src/main/resources/interpreter-setting.json b/hbase/src/main/resources/interpreter-setting.json
index 5f48cf6cb7..95aba64648 100644
--- a/hbase/src/main/resources/interpreter-setting.json
+++ b/hbase/src/main/resources/interpreter-setting.json
@@ -9,19 +9,19 @@
"propertyName": "hbase.home",
"defaultValue": "/usr/lib/hbase/",
"description": "Installation directory of HBase",
- "type": "text"
+ "widget": "string"
},
"hbase.ruby.sources": {
"propertyName": "hbase.ruby.sources",
"defaultValue": "lib/ruby",
"description": "Path to Ruby scripts relative to 'hbase.home'",
- "type": "text"
+ "widget": "string"
},
"zeppelin.hbase.test.mode": {
"propertyName": "zeppelin.hbase.test.mode",
"defaultValue": false,
"description": "Disable checks for unit and manual tests",
- "type": "checkbox"
+ "widget": "checkbox"
}
},
"editor": {
diff --git a/helium-dev/src/main/resources/interpreter-setting.json b/helium-dev/src/main/resources/interpreter-setting.json
index 9383f27a6f..f50d66e6df 100644
--- a/helium-dev/src/main/resources/interpreter-setting.json
+++ b/helium-dev/src/main/resources/interpreter-setting.json
@@ -9,7 +9,7 @@
"propertyName": "port",
"defaultValue": "jdbc:postgresql://localhost:5432/",
"description": "The URL for JDBC.",
- "type": "text"
+ "widget": "string"
}
},
"editor": {
diff --git a/ignite/src/main/resources/interpreter-setting.json b/ignite/src/main/resources/interpreter-setting.json
index 2419bee40a..74b035f2a0 100644
--- a/ignite/src/main/resources/interpreter-setting.json
+++ b/ignite/src/main/resources/interpreter-setting.json
@@ -9,28 +9,28 @@
"propertyName": "ignite.addresses",
"defaultValue": "127.0.0.1:47500..47509",
"description": "Comma separated list of addresses (e.g. 127.0.0.1:47500 or 127.0.0.1:47500..47509)",
- "type": "text"
+ "widget": "text"
},
"ignite.clientMode": {
"envName": null,
"propertyName": "ignite.clientMode",
"defaultValue": true,
"description": "Client mode. true or false",
- "type": "checkbox"
+ "widget": "checkbox"
},
"ignite.config.url": {
"envName": null,
"propertyName": "ignite.config.url",
"defaultValue": "",
"description": "Configuration URL. Overrides all other settings.",
- "type": "text"
+ "widget": "url"
},
"ignite.peerClassLoadingEnabled": {
"envName": null,
"propertyName": "ignite.peerClassLoadingEnabled",
"defaultValue": true,
"description": "Peer class loading enabled. True or false",
- "type": "checkbox"
+ "widget": "checkbox"
}
}
},
@@ -44,7 +44,7 @@
"propertyName": "ignite.jdbc.url",
"defaultValue": "jdbc:ignite:cfg://default-ignite-jdbc.xml",
"description": "Ignite JDBC connection URL.",
- "type": "text"
+ "widget": "string"
}
}
}
diff --git a/jdbc/src/main/resources/interpreter-setting.json b/jdbc/src/main/resources/interpreter-setting.json
index 4868d32ba3..5e70e535fe 100644
--- a/jdbc/src/main/resources/interpreter-setting.json
+++ b/jdbc/src/main/resources/interpreter-setting.json
@@ -9,83 +9,84 @@
"propertyName": "default.url",
"defaultValue": "jdbc:postgresql://localhost:5432/",
"description": "The URL for JDBC.",
- "type": "text"
+ "widget": "string"
},
"default.user": {
"envName": null,
"propertyName": "default.user",
"defaultValue": "gpadmin",
"description": "The JDBC user name",
- "type": "text"
+ "widget": "string"
},
"default.password": {
"envName": null,
"propertyName": "default.password",
"defaultValue": "",
"description": "The JDBC user password",
- "type": "password"
+ "widget": "password"
},
"default.driver": {
"envName": null,
"propertyName": "default.driver",
"defaultValue": "org.postgresql.Driver",
"description": "JDBC Driver Name",
- "type": "text"
+ "widget": "string"
},
"default.completer.schemaFilters": {
"envName": null,
"propertyName": "default.completer.schemaFilters",
"defaultValue": "",
- "description": "Сomma separated schema (schema = catalog = database) filters to get metadata for completions. Supports '%' symbol is equivalent to any set of characters. (ex. prod_v_%,public%,info)"
+ "description": "Сomma separated schema (schema = catalog = database) filters to get metadata for completions. Supports '%' symbol is equivalent to any set of characters. (ex. prod_v_%,public%,info)",
+ "widget": "text"
},
"default.precode": {
"envName": null,
"propertyName": "zeppelin.jdbc.precode",
"defaultValue": "",
"description": "SQL which executes while opening connection",
- "type": "text"
+ "widget": "text"
},
"common.max_count": {
"envName": null,
"propertyName": "common.max_count",
"defaultValue": "1000",
"description": "Max number of SQL result to display.",
- "type": "text"
+ "widget": "number"
},
"zeppelin.jdbc.auth.type": {
"envName": null,
"propertyName": "zeppelin.jdbc.auth.type",
"defaultValue": "",
"description": "If auth type is needed, Example: KERBEROS",
- "type": "text"
+ "widget": "string"
},
"zeppelin.jdbc.concurrent.use": {
"envName": null,
"propertyName": "zeppelin.jdbc.concurrent.use",
"defaultValue": true,
"description": "Use parallel scheduler",
- "type": "checkbox"
+ "widget": "checkbox"
},
"zeppelin.jdbc.concurrent.max_connection": {
"envName": null,
"propertyName": "zeppelin.jdbc.concurrent.max_connection",
"defaultValue": "10",
"description": "Number of concurrent execution",
- "type": "text"
+ "widget": "number"
},
"zeppelin.jdbc.keytab.location": {
"envName": null,
"propertyName": "zeppelin.jdbc.keytab.location",
"defaultValue": "",
"description": "Kerberos keytab location",
- "type": "text"
+ "widget": "string"
},
"zeppelin.jdbc.principal": {
"envName": null,
"propertyName": "zeppelin.jdbc.principal",
"defaultValue": "",
"description": "Kerberos principal",
- "type": "text"
+ "widget": "string"
}
},
"editor": {
diff --git a/kylin/src/main/resources/interpreter-setting.json b/kylin/src/main/resources/interpreter-setting.json
index dc2ac70f4d..7e87f08b14 100644
--- a/kylin/src/main/resources/interpreter-setting.json
+++ b/kylin/src/main/resources/interpreter-setting.json
@@ -9,49 +9,49 @@
"propertyName": "kylin.api.url",
"defaultValue": "http://localhost:7070/kylin/api/query",
"description": "Kylin API",
- "type": "text"
+ "widget": "url"
},
"kylin.api.user": {
"envName": null,
"propertyName": "kylin.api.user",
"defaultValue": "ADMIN",
"description": "Kylin username",
- "type": "text"
+ "widget": "string"
},
"kylin.api.password": {
"envName": null,
"propertyName": "kylin.api.password",
"defaultValue": "KYLIN",
"description": "Kylin password",
- "type": "password"
+ "widget": "password"
},
"kylin.query.project": {
"envName": null,
"propertyName": "kylin.query.project",
"defaultValue": "learn_kylin",
"description": "Default Kylin project name",
- "type": "text"
+ "widget": "text"
},
"kylin.query.offset": {
"envName": null,
"propertyName": "kylin.query.offset",
"defaultValue": "0",
"description": "Kylin query offset",
- "type": "text"
+ "widget": "number"
},
"kylin.query.limit": {
"envName": null,
"propertyName": "kylin.query.limit",
"defaultValue": "5000",
"description": "Kylin query limit",
- "type": "text"
+ "widget": "number"
},
"kylin.query.ispartial": {
"envName": null,
"propertyName": "kylin.query.ispartial",
"defaultValue": true,
"description": "Kylin query partial flag, deprecated",
- "type": "checkbox"
+ "widget": "checkbox"
}
},
"editor": {
diff --git a/lens/src/main/resources/interpreter-setting.json b/lens/src/main/resources/interpreter-setting.json
index 017bbdec92..32d5236919 100644
--- a/lens/src/main/resources/interpreter-setting.json
+++ b/lens/src/main/resources/interpreter-setting.json
@@ -9,49 +9,49 @@
"propertyName": "zeppelin.lens.run.concurrent",
"defaultValue": true,
"description": "Run concurrent Lens Sessions",
- "type": "checkbox"
+ "widget": "checkbox"
},
"zeppelin.lens.maxThreads": {
"envName": null,
"propertyName": "zeppelin.lens.maxThreads",
"defaultValue": "10",
"description": "If concurrency is true then how many threads?",
- "type": "text"
+ "widget": "number"
},
"zeppelin.lens.maxResults": {
"envName": null,
"propertyName": "zeppelin.lens.maxResults",
"defaultValue": "1000",
"description": "max number of rows to display",
- "type": "text"
+ "widget": "number"
},
"lens.server.base.url": {
"envName": null,
"propertyName": "lens.server.base.url",
"defaultValue": "http://:/lensapi",
"description": "The URL for Lens Server",
- "type": "text"
+ "widget": "url"
},
"lens.client.dbname": {
"envName": null,
"propertyName": "lens.client.dbname",
"defaultValue": "default",
"description": "The database schema name",
- "type": "text"
+ "widget": "string"
},
"lens.query.enable.persistent.resultset": {
"envName": null,
"propertyName": "lens.query.enable.persistent.resultset",
"defaultValue": false,
"description": "Apache Lens to persist result in HDFS?",
- "type": "checkbox"
+ "widget": "checkbox"
},
"lens.session.cluster.user": {
"envName": null,
"propertyName": "lens.session.cluster.user",
"defaultValue": "default",
"description": "Hadoop cluster username",
- "type": "text"
+ "widget": "string"
}
}
}
diff --git a/livy/src/main/resources/interpreter-setting.json b/livy/src/main/resources/interpreter-setting.json
index e9ec185ed9..5f1eb38722 100644
--- a/livy/src/main/resources/interpreter-setting.json
+++ b/livy/src/main/resources/interpreter-setting.json
@@ -10,104 +10,104 @@
"propertyName": "zeppelin.livy.url",
"defaultValue": "http://localhost:8998",
"description": "The URL for Livy Server.",
- "type": "text"
+ "widget": "url"
},
"zeppelin.livy.session.create_timeout": {
"envName": "ZEPPELIN_LIVY_SESSION_CREATE_TIMEOUT",
"propertyName": "zeppelin.livy.session.create_timeout",
"defaultValue": "120",
"description": "Livy Server create session timeout (seconds).",
- "type": "text"
+ "widget": "number"
},
"livy.spark.driver.cores": {
"propertyName": "livy.spark.driver.cores",
"defaultValue": "",
"description": "Driver cores. ex) 1, 2",
- "type": "text"
+ "widget": "number"
},
"livy.spark.driver.memory": {
"propertyName": "livy.spark.driver.memory",
"defaultValue": "",
"description": "Driver memory. ex) 512m, 32g",
- "type": "text"
+ "widget": "string"
},
"livy.spark.executor.instances": {
"propertyName": "livy.spark.executor.instances",
"defaultValue": "",
"description": "Executor instances. ex) 1, 4",
- "type": "text"
+ "widget": "number"
},
"livy.spark.executor.cores": {
"propertyName": "livy.spark.executor.cores",
"defaultValue": "",
"description": "Num cores per executor. ex) 1, 4",
- "type": "text"
+ "widget": "number"
},
"livy.spark.executor.memory": {
"propertyName": "livy.spark.executor.memory",
"defaultValue": "",
"description": "Executor memory per worker instance. ex) 512m, 32g",
- "type": "text"
+ "widget": "string"
},
"livy.spark.dynamicAllocation.enabled": {
"propertyName": "livy.spark.dynamicAllocation.enabled",
- "defaultValue": "",
+ "defaultValue": false,
"description": "Use dynamic resource allocation",
- "type": "text"
+ "widget": "checkbox"
},
"livy.spark.dynamicAllocation.cachedExecutorIdleTimeout": {
"propertyName": "livy.spark.dynamicAllocation.cachedExecutorIdleTimeout",
"defaultValue": "",
"description": "Remove an executor which has cached data blocks",
- "type": "text"
+ "widget": "string"
},
"livy.spark.dynamicAllocation.minExecutors": {
"propertyName": "livy.spark.dynamicAllocation.minExecutors",
"defaultValue": "",
"description": "Lower bound for the number of executors if dynamic allocation is enabled.",
- "type": "text"
+ "widget": "number"
},
"livy.spark.dynamicAllocation.initialExecutors": {
"propertyName": "livy.spark.dynamicAllocation.initialExecutors",
"defaultValue": "",
"description": "Initial number of executors to run if dynamic allocation is enabled.",
- "type": "text"
+ "widget": "number"
},
"livy.spark.dynamicAllocation.maxExecutors": {
"propertyName": "livy.spark.dynamicAllocation.maxExecutors",
"defaultValue": "",
"description": "Upper bound for the number of executors if dynamic allocation is enabled.",
- "type": "text"
+ "widget": "number"
},
"zeppelin.livy.principal": {
"propertyName": "zeppelin.livy.principal",
"defaultValue": "",
"description": "Kerberos principal to authenticate livy",
- "type": "text"
+ "widget": "string"
},
"zeppelin.livy.keytab": {
"propertyName": "zeppelin.livy.keytab",
"defaultValue": "",
"description": "Kerberos keytab to authenticate livy",
- "type": "text"
+ "widget": "text"
},
"zeppelin.livy.pull_status.interval.millis": {
"propertyName": "zeppelin.livy.pull_status.interval.millis",
"defaultValue": "1000",
"description": "The interval for checking paragraph execution status",
- "type": "text"
+ "widget": "number"
},
"livy.spark.jars.packages": {
"propertyName": "livy.spark.jars.packages",
"defaultValue": "",
"description": "Adding extra libraries to livy interpreter",
- "type": "text"
+ "widget": "text"
},
"zeppelin.livy.displayAppInfo": {
"propertyName": "zeppelin.livy.displayAppInfo",
"defaultValue": false,
"description": "Whether display app info",
- "type": "checkbox"
+ "widget": "checkbox"
}
},
"option": {
@@ -134,19 +134,19 @@
"propertyName": "zeppelin.livy.spark.sql.maxResult",
"defaultValue": "1000",
"description": "Max number of Spark SQL result to display.",
- "type": "text"
+ "widget": "number"
},
"zeppelin.livy.spark.sql.field.truncate": {
"propertyName": "zeppelin.livy.spark.sql.field.truncate",
"defaultValue": true,
"description": "If true, truncate field values longer than 20 characters.",
- "type": "checkbox"
+ "widget": "checkbox"
},
"zeppelin.livy.concurrentSQL": {
"propertyName": "zeppelin.livy.concurrentSQL",
"defaultValue": false,
"description": "Execute multiple SQL concurrently if set true.",
- "type": "checkbox"
+ "widget": "checkbox"
}
},
"option": {
diff --git a/markdown/src/main/resources/interpreter-setting.json b/markdown/src/main/resources/interpreter-setting.json
index 6724657a89..37ae98bff4 100644
--- a/markdown/src/main/resources/interpreter-setting.json
+++ b/markdown/src/main/resources/interpreter-setting.json
@@ -9,7 +9,7 @@
"propertyName": "markdown.parser.type",
"defaultValue": "pegdown",
"description": "Markdown Parser Type. Available values: pegdown, markdown4j. Default = pegdown",
- "type": "text"
+ "widget": "string"
}
},
"editor": {
diff --git a/pig/src/main/resources/interpreter-setting.json b/pig/src/main/resources/interpreter-setting.json
index f2ef00bcfc..96e13f5499 100644
--- a/pig/src/main/resources/interpreter-setting.json
+++ b/pig/src/main/resources/interpreter-setting.json
@@ -9,14 +9,14 @@
"propertyName": "zeppelin.pig.execType",
"defaultValue": "mapreduce",
"description": "local | mapreduce | tez",
- "type": "text"
+ "widget": "string"
},
"zeppelin.pig.includeJobStats": {
"envName": null,
"propertyName": "zeppelin.pig.includeJobStats",
"defaultValue": false,
"description": "flag to include job stats in output",
- "type": "checkbox"
+ "widget": "checkbox"
}
},
"editor": {
@@ -34,14 +34,14 @@
"propertyName": "zeppelin.pig.execType",
"defaultValue": "mapreduce",
"description": "local | mapreduce | tez",
- "type": "text"
+ "widget": "string"
},
"zeppelin.pig.maxResult": {
"envName": null,
"propertyName": "zeppelin.pig.maxResult",
"defaultValue": "1000",
"description": "max row number for %pig.query",
- "type": "text"
+ "widget": "number"
}
},
"editor": {
diff --git a/python/src/main/resources/interpreter-setting.json b/python/src/main/resources/interpreter-setting.json
index 65d26e3c88..03f9b33179 100644
--- a/python/src/main/resources/interpreter-setting.json
+++ b/python/src/main/resources/interpreter-setting.json
@@ -9,14 +9,14 @@
"propertyName": "zeppelin.python",
"defaultValue": "python",
"description": "Python directory. It is set to python by default.(assume python is in your $PATH)",
- "type": "text"
+ "widget": "string"
},
"zeppelin.python.maxResult": {
"envName": null,
"propertyName": "zeppelin.python.maxResult",
"defaultValue": "1000",
"description": "Max number of dataframe rows to display.",
- "type": "text"
+ "widget": "number"
}
},
"editor": {
diff --git a/r/src/main/resources/interpreter-setting.json b/r/src/main/resources/interpreter-setting.json
index 2df4a367a2..5fb8698acf 100644
--- a/r/src/main/resources/interpreter-setting.json
+++ b/r/src/main/resources/interpreter-setting.json
@@ -7,22 +7,22 @@
"rhadoop.cmd": {
"envName": "HADOOP_CMD",
"defaultValue": "",
- "type": "text"
+ "widget": "text"
},
"rhadooop.streamingjar": {
"envName": "HADOOP_STREAMING",
"defaultValue": "",
- "type": "text"
+ "widget": "text"
},
"rscala.debug": {
"envName": "RSCALA_DEBUG",
"defaultValue": false,
- "type": "checkbox"
+ "widget": "checkbox"
},
"rscala.timeout": {
"envName": "RSCALA_TIMEOUT",
"defaultValue": "60",
- "type": "text"
+ "widget": "number"
}
}
},
@@ -34,22 +34,22 @@
"rhadoop.cmd": {
"envName": "HADOOP_CMD",
"defaultValue": "",
- "type": "text"
+ "widget": "text"
},
"rhadooop.streamingjar": {
"envName": "HADOOP_STREAMING",
"defaultValue": "",
- "type": "text"
+ "widget": "text"
},
"rscala.debug": {
"envName": "RSCALA_DEBUG",
"defaultValue": false,
- "type": "checkbox"
+ "widget": "checkbox"
},
"rscala.timeout": {
"envName": "RSCALA_TIMEOUT",
"defaultValue": "60",
- "type": "text"
+ "widget": "number"
}
}
}
diff --git a/scalding/src/main/resources/interpreter-setting.json b/scalding/src/main/resources/interpreter-setting.json
index 4fdb0a2261..33458448b0 100644
--- a/scalding/src/main/resources/interpreter-setting.json
+++ b/scalding/src/main/resources/interpreter-setting.json
@@ -8,13 +8,13 @@
"envName": null,
"defaultValue": "--local --repl",
"description": "Arguments for scalding REPL",
- "type": "text"
+ "widget": "text"
},
"max.open.instances": {
"envName": null,
"defaultValue": "50",
"description": "Maximum number of open interpreter instances",
- "type": "text"
+ "widget": "number"
}
}
}
diff --git a/shell/src/main/resources/interpreter-setting.json b/shell/src/main/resources/interpreter-setting.json
index 811b58a27f..cae496b741 100644
--- a/shell/src/main/resources/interpreter-setting.json
+++ b/shell/src/main/resources/interpreter-setting.json
@@ -9,28 +9,28 @@
"propertyName": "shell.command.timeout.millisecs",
"defaultValue": "60000",
"description": "Shell command time out in millisecs. Default = 60000",
- "type": "text"
+ "widget": "number"
},
"zeppelin.shell.auth.type": {
"envName": null,
"propertyName": "zeppelin.shell.auth.type",
"defaultValue": "",
"description": "If auth type is needed, Example: KERBEROS",
- "type": "text"
+ "widget": "string"
},
"zeppelin.shell.keytab.location": {
"envName": null,
"propertyName": "zeppelin.shell.keytab.location",
"defaultValue": "",
"description": "Kerberos keytab location",
- "type": "text"
+ "widget": "string"
},
"zeppelin.shell.principal": {
"envName": null,
"propertyName": "zeppelin.shell.principal",
"defaultValue": "",
"description": "Kerberos principal",
- "type": "text"
+ "widget": "string"
}
},
"editor": {
diff --git a/spark/src/main/java/org/apache/zeppelin/spark/SparkInterpreter.java b/spark/src/main/java/org/apache/zeppelin/spark/SparkInterpreter.java
index cb233bc020..d30647b60f 100644
--- a/spark/src/main/java/org/apache/zeppelin/spark/SparkInterpreter.java
+++ b/spark/src/main/java/org/apache/zeppelin/spark/SparkInterpreter.java
@@ -55,7 +55,7 @@ import org.apache.zeppelin.interpreter.Interpreter;
import org.apache.zeppelin.interpreter.InterpreterContext;
import org.apache.zeppelin.interpreter.InterpreterException;
import org.apache.zeppelin.interpreter.InterpreterHookRegistry;
-import org.apache.zeppelin.interpreter.InterpreterPropertyType;
+import org.apache.zeppelin.interpreter.InterpreterPropertyWidget;
import org.apache.zeppelin.interpreter.InterpreterResult;
import org.apache.zeppelin.interpreter.InterpreterResult.Code;
import org.apache.zeppelin.interpreter.InterpreterUtils;
@@ -527,14 +527,14 @@ public class SparkInterpreter extends Interpreter {
private void setupConfForPySpark(SparkConf conf) {
Object pysparkBaseProperty =
- new DefaultInterpreterProperty("SPARK_HOME", null, null, null, InterpreterPropertyType.text)
- .getValue();
+ new DefaultInterpreterProperty("SPARK_HOME", null, null, null,
+ InterpreterPropertyWidget.text).getValue();
String pysparkBasePath = pysparkBaseProperty != null ? pysparkBaseProperty.toString() : null;
File pysparkPath;
if (null == pysparkBasePath) {
pysparkBasePath =
new DefaultInterpreterProperty("ZEPPELIN_HOME", "zeppelin.home", "../", null,
- InterpreterPropertyType.text).getValue().toString();
+ InterpreterPropertyWidget.text).getValue().toString();
pysparkPath = new File(pysparkBasePath,
"interpreter" + File.separator + "spark" + File.separator + "pyspark");
} else {
@@ -581,13 +581,13 @@ public class SparkInterpreter extends Interpreter {
private void setupConfForSparkR(SparkConf conf) {
Object sparkRBaseProperty =
new DefaultInterpreterProperty("SPARK_HOME", null, null, null,
- InterpreterPropertyType.text).getValue();
+ InterpreterPropertyWidget.text).getValue();
String sparkRBasePath = sparkRBaseProperty != null ? sparkRBaseProperty.toString() : null;
File sparkRPath;
if (null == sparkRBasePath) {
sparkRBasePath =
new DefaultInterpreterProperty("ZEPPELIN_HOME", "zeppelin.home", "../", null,
- InterpreterPropertyType.text).getValue().toString();
+ InterpreterPropertyWidget.text).getValue().toString();
sparkRPath = new File(sparkRBasePath,
"interpreter" + File.separator + "spark" + File.separator + "R");
} else {
diff --git a/spark/src/main/resources/interpreter-setting.json b/spark/src/main/resources/interpreter-setting.json
index 0201e6b689..ab04e5729c 100644
--- a/spark/src/main/resources/interpreter-setting.json
+++ b/spark/src/main/resources/interpreter-setting.json
@@ -10,63 +10,63 @@
"propertyName": "spark.executor.memory",
"defaultValue": "",
"description": "Executor memory per worker instance. ex) 512m, 32g",
- "type": "text"
+ "widget": "string"
},
"args": {
"envName": null,
"propertyName": null,
"defaultValue": "",
"description": "spark commandline args",
- "type": "text"
+ "widget": "text"
},
"zeppelin.spark.useHiveContext": {
"envName": "ZEPPELIN_SPARK_USEHIVECONTEXT",
"propertyName": "zeppelin.spark.useHiveContext",
"defaultValue": true,
"description": "Use HiveContext instead of SQLContext if it is true.",
- "type": "checkbox"
+ "widget": "checkbox"
},
"spark.app.name": {
"envName": "SPARK_APP_NAME",
"propertyName": "spark.app.name",
"defaultValue": "Zeppelin",
"description": "The name of spark application.",
- "type": "text"
+ "widget": "string"
},
"zeppelin.spark.printREPLOutput": {
"envName": null,
"propertyName": "zeppelin.spark.printREPLOutput",
"defaultValue": true,
"description": "Print REPL output",
- "type": "checkbox"
+ "widget": "checkbox"
},
"spark.cores.max": {
"envName": null,
"propertyName": "spark.cores.max",
"defaultValue": "",
"description": "Total number of cores to use. Empty value uses all available core.",
- "type": "text"
+ "widget": "number"
},
"zeppelin.spark.maxResult": {
"envName": "ZEPPELIN_SPARK_MAXRESULT",
"propertyName": "zeppelin.spark.maxResult",
"defaultValue": "1000",
"description": "Max number of Spark SQL result to display.",
- "type": "text"
+ "widget": "number"
},
"master": {
"envName": "MASTER",
"propertyName": "spark.master",
"defaultValue": "local[*]",
"description": "Spark master uri. ex) spark://masterhost:7077",
- "type": "text"
+ "widget": "string"
},
"zeppelin.spark.unSupportedVersionCheck": {
"envName": null,
"propertyName": "zeppelin.spark.enableSupportedVersionCheck",
"defaultValue": true,
"description": "Do not change - developer only setting, not for production use",
- "type": "checkbox"
+ "widget": "checkbox"
}
},
"editor": {
@@ -84,28 +84,28 @@
"propertyName": "zeppelin.spark.concurrentSQL",
"defaultValue": false,
"description": "Execute multiple SQL concurrently if set true.",
- "type": "checkbox"
+ "widget": "checkbox"
},
"zeppelin.spark.sql.stacktrace": {
"envName": "ZEPPELIN_SPARK_SQL_STACKTRACE",
"propertyName": "zeppelin.spark.sql.stacktrace",
"defaultValue": false,
"description": "Show full exception stacktrace for SQL queries if set to true.",
- "type": "checkbox"
+ "widget": "checkbox"
},
"zeppelin.spark.maxResult": {
"envName": "ZEPPELIN_SPARK_MAXRESULT",
"propertyName": "zeppelin.spark.maxResult",
"defaultValue": "1000",
"description": "Max number of Spark SQL result to display.",
- "type": "text"
+ "widget": "number"
},
"zeppelin.spark.importImplicit": {
"envName": "ZEPPELIN_SPARK_IMPORTIMPLICIT",
"propertyName": "zeppelin.spark.importImplicit",
"defaultValue": true,
"description": "Import implicits, UDF collection, and sql if set true. true by default.",
- "type": "checkbox"
+ "widget": "checkbox"
}
},
"editor": {
@@ -123,14 +123,14 @@
"propertyName": null,
"defaultValue": "local-repo",
"description": "local repository for dependency loader",
- "type": "text"
+ "widget": "string"
},
"zeppelin.dep.additionalRemoteRepository": {
"envName": null,
"propertyName": null,
"defaultValue": "spark-packages,http://dl.bintray.com/spark-packages/maven,false;",
"description": "A list of 'id,remote-repository-URL,is-snapshot;' for each remote repository.",
- "type": "text"
+ "widget": "text"
}
},
"editor": {
@@ -148,7 +148,7 @@
"propertyName": null,
"defaultValue": "python",
"description": "Python command to run pyspark with",
- "type": "text"
+ "widget": "string"
}
},
"editor": {
diff --git a/spark/src/main/sparkr-resources/interpreter-setting.json b/spark/src/main/sparkr-resources/interpreter-setting.json
index a341710e9a..d28f75c444 100644
--- a/spark/src/main/sparkr-resources/interpreter-setting.json
+++ b/spark/src/main/sparkr-resources/interpreter-setting.json
@@ -10,63 +10,63 @@
"propertyName": "spark.executor.memory",
"defaultValue": "",
"description": "Executor memory per worker instance. ex) 512m, 32g",
- "type": "text"
+ "widget": "string"
},
"args": {
"envName": null,
"propertyName": null,
"defaultValue": "",
"description": "spark commandline args",
- "type": "text"
+ "widget": "text"
},
"zeppelin.spark.useHiveContext": {
"envName": "ZEPPELIN_SPARK_USEHIVECONTEXT",
"propertyName": "zeppelin.spark.useHiveContext",
"defaultValue": true,
"description": "Use HiveContext instead of SQLContext if it is true.",
- "type": "checkbox"
+ "widget": "checkbox"
},
"spark.app.name": {
"envName": "SPARK_APP_NAME",
"propertyName": "spark.app.name",
"defaultValue": "Zeppelin",
"description": "The name of spark application.",
- "type": "text"
+ "widget": "string"
},
"zeppelin.spark.printREPLOutput": {
"envName": null,
"propertyName": "zeppelin.spark.printREPLOutput",
"defaultValue": true,
"description": "Print REPL output",
- "type": "checkbox"
+ "widget": "checkbox"
},
"spark.cores.max": {
"envName": null,
"propertyName": "spark.cores.max",
"defaultValue": "",
"description": "Total number of cores to use. Empty value uses all available core.",
- "type": "text"
+ "widget": "number"
},
"zeppelin.spark.maxResult": {
"envName": "ZEPPELIN_SPARK_MAXRESULT",
"propertyName": "zeppelin.spark.maxResult",
"defaultValue": "1000",
"description": "Max number of Spark SQL result to display.",
- "type": "text"
+ "widget": "number"
},
"master": {
"envName": "MASTER",
"propertyName": "spark.master",
"defaultValue": "local[*]",
"description": "Spark master uri. ex) spark://masterhost:7077",
- "type": "text"
+ "widget": "string"
},
"zeppelin.spark.unSupportedVersionCheck": {
"envName": null,
"propertyName": "zeppelin.spark.enableSupportedVersionCheck",
"defaultValue": true,
"description": "Do not change - developer only setting, not for production use",
- "type": "checkbox"
+ "widget": "checkbox"
}
},
"editor": {
@@ -83,28 +83,28 @@
"propertyName": "zeppelin.spark.concurrentSQL",
"defaultValue": false,
"description": "Execute multiple SQL concurrently if set true.",
- "type": "checkbox"
+ "widget": "checkbox"
},
"zeppelin.spark.sql.stacktrace": {
"envName": "ZEPPELIN_SPARK_SQL_STACKTRACE",
"propertyName": "zeppelin.spark.sql.stacktrace",
"defaultValue": false,
"description": "Show full exception stacktrace for SQL queries if set to true.",
- "type": "checkbox"
+ "widget": "checkbox"
},
"zeppelin.spark.maxResult": {
"envName": "ZEPPELIN_SPARK_MAXRESULT",
"propertyName": "zeppelin.spark.maxResult",
"defaultValue": "1000",
"description": "Max number of Spark SQL result to display.",
- "type": "text"
+ "widget": "number"
},
"zeppelin.spark.importImplicit": {
"envName": "ZEPPELIN_SPARK_IMPORTIMPLICIT",
"propertyName": "zeppelin.spark.importImplicit",
"defaultValue": true,
"description": "Import implicits, UDF collection, and sql if set true. true by default.",
- "type": "checkbox"
+ "widget": "checkbox"
}
},
"editor": {
@@ -121,14 +121,14 @@
"propertyName": null,
"defaultValue": "local-repo",
"description": "local repository for dependency loader",
- "type": "text"
+ "widget": "string"
},
"zeppelin.dep.additionalRemoteRepository": {
"envName": null,
"propertyName": null,
"defaultValue": "spark-packages,http://dl.bintray.com/spark-packages/maven,false;",
"description": "A list of 'id,remote-repository-URL,is-snapshot;' for each remote repository.",
- "type": "text"
+ "widget": "text"
}
},
"editor": {
@@ -145,7 +145,7 @@
"propertyName": null,
"defaultValue": "python",
"description": "Python command to run pyspark with",
- "type": "text"
+ "widget": "string"
}
},
"editor": {
@@ -162,28 +162,28 @@
"propertyName": "zeppelin.R.knitr",
"defaultValue": true,
"description": "whether use knitr or not",
- "type": "checkbox"
+ "widget": "checkbox"
},
"zeppelin.R.cmd": {
"envName": "ZEPPELIN_R_CMD",
"propertyName": "zeppelin.R.cmd",
"defaultValue": "R",
"description": "R repl path",
- "type": "text"
+ "widget": "string"
},
"zeppelin.R.image.width": {
"envName": "ZEPPELIN_R_IMAGE_WIDTH",
"propertyName": "zeppelin.R.image.width",
"defaultValue": "100%",
"description": "",
- "type": "text"
+ "widget": "number"
},
"zeppelin.R.render.options": {
"envName": "ZEPPELIN_R_RENDER_OPTIONS",
"propertyName": "zeppelin.R.render.options",
"defaultValue": "out.format = 'html', comment = NA, echo = FALSE, results = 'asis', message = F, warning = F",
"description": "",
- "type": "text"
+ "widget": "text"
}
},
"editor": {
diff --git a/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/DefaultInterpreterProperty.java b/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/DefaultInterpreterProperty.java
index f863184943..89df8c0f82 100644
--- a/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/DefaultInterpreterProperty.java
+++ b/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/DefaultInterpreterProperty.java
@@ -25,20 +25,20 @@ public class DefaultInterpreterProperty {
String propertyName;
Object defaultValue;
String description;
- InterpreterPropertyType type;
+ InterpreterPropertyWidget widget;
public DefaultInterpreterProperty(String envName, String propertyName, Object defaultValue,
- String description, InterpreterPropertyType type) {
+ String description, InterpreterPropertyWidget widget) {
this.envName = envName;
this.propertyName = propertyName;
this.defaultValue = defaultValue;
this.description = description;
- this.type = type;
+ this.widget = widget;
}
public DefaultInterpreterProperty(Object defaultValue, String description,
- InterpreterPropertyType type) {
- this(null, null, defaultValue, description, type);
+ InterpreterPropertyWidget widget) {
+ this(null, null, defaultValue, description, widget);
}
public String getEnvName() {
@@ -73,12 +73,12 @@ public class DefaultInterpreterProperty {
this.description = description;
}
- public InterpreterPropertyType getType() {
- return type;
+ public InterpreterPropertyWidget getWidget() {
+ return widget;
}
- public void setType(InterpreterPropertyType type) {
- this.type = type;
+ public void setWidget(InterpreterPropertyWidget widget) {
+ this.widget = widget;
}
public int hashCode() {
@@ -110,6 +110,6 @@ public class DefaultInterpreterProperty {
@Override
public String toString() {
return String.format("{envName=%s, propertyName=%s, defaultValue=%s, description=%20s, " +
- "type=%s}", envName, propertyName, defaultValue, description, type);
+ "type=%s}", envName, propertyName, defaultValue, description, widget);
}
}
diff --git a/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterProperty.java b/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterProperty.java
index db11c5d1aa..2525d6bb2e 100644
--- a/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterProperty.java
+++ b/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterProperty.java
@@ -23,12 +23,12 @@ package org.apache.zeppelin.interpreter;
public class InterpreterProperty {
private String name;
private Object value;
- private InterpreterPropertyType type;
+ private InterpreterPropertyWidget widget;
- public InterpreterProperty(String name, Object value, InterpreterPropertyType type) {
+ public InterpreterProperty(String name, Object value, InterpreterPropertyWidget widget) {
this.name = name;
this.value = value;
- this.type = type;
+ this.widget = widget;
}
public String getName() {
@@ -47,11 +47,11 @@ public class InterpreterProperty {
this.value = value;
}
- public InterpreterPropertyType getType() {
- return type;
+ public InterpreterPropertyWidget getWidget() {
+ return widget;
}
- public void setType(InterpreterPropertyType type) {
- this.type = type;
+ public void setWidget(InterpreterPropertyWidget widget) {
+ this.widget = widget;
}
}
diff --git a/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterPropertyBuilder.java b/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterPropertyBuilder.java
index 3f9e2ca6a5..9baef948e5 100644
--- a/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterPropertyBuilder.java
+++ b/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterPropertyBuilder.java
@@ -28,7 +28,7 @@ public class InterpreterPropertyBuilder {
public InterpreterPropertyBuilder add(String name, String defaultValue, String description){
properties.put(name,
- new DefaultInterpreterProperty(defaultValue, description, InterpreterPropertyType.text));
+ new DefaultInterpreterProperty(defaultValue, description, InterpreterPropertyWidget.text));
return this;
}
@@ -36,7 +36,7 @@ public class InterpreterPropertyBuilder {
String defaultValue, String description){
properties.put(name,
new DefaultInterpreterProperty(envName, propertyName, defaultValue, description,
- InterpreterPropertyType.text));
+ InterpreterPropertyWidget.text));
return this;
}
diff --git a/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterPropertyType.java b/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterPropertyWidget.java
similarity index 89%
rename from zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterPropertyType.java
rename to zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterPropertyWidget.java
index 195f827f04..9606fb191c 100644
--- a/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterPropertyType.java
+++ b/zeppelin-interpreter/src/main/java/org/apache/zeppelin/interpreter/InterpreterPropertyWidget.java
@@ -18,10 +18,13 @@
package org.apache.zeppelin.interpreter;
/**
- * Types of interpreter properties
+ * Widgets of interpreter properties
*/
-public enum InterpreterPropertyType {
+public enum InterpreterPropertyWidget {
text,
+ string,
+ number,
+ url,
password,
checkbox
}
diff --git a/zeppelin-server/src/test/java/org/apache/zeppelin/rest/AbstractTestRestApi.java b/zeppelin-server/src/test/java/org/apache/zeppelin/rest/AbstractTestRestApi.java
index 3237808a1b..0b0c018905 100644
--- a/zeppelin-server/src/test/java/org/apache/zeppelin/rest/AbstractTestRestApi.java
+++ b/zeppelin-server/src/test/java/org/apache/zeppelin/rest/AbstractTestRestApi.java
@@ -45,7 +45,7 @@ import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.zeppelin.conf.ZeppelinConfiguration;
import org.apache.zeppelin.interpreter.InterpreterProperty;
-import org.apache.zeppelin.interpreter.InterpreterPropertyType;
+import org.apache.zeppelin.interpreter.InterpreterPropertyWidget;
import org.apache.zeppelin.interpreter.InterpreterSetting;
import org.apache.zeppelin.server.ZeppelinServer;
import org.hamcrest.Description;
@@ -205,14 +205,14 @@ public abstract class AbstractTestRestApi {
if ("true".equals(System.getenv("CI"))) {
// set spark master and other properties
sparkProperties.put("master",
- new InterpreterProperty("master", "local[2]", InterpreterPropertyType.text));
+ new InterpreterProperty("master", "local[2]", InterpreterPropertyWidget.text));
sparkProperties.put("spark.cores.max",
- new InterpreterProperty("spark.cores.max", "2", InterpreterPropertyType.text));
+ new InterpreterProperty("spark.cores.max", "2", InterpreterPropertyWidget.text));
sparkProperties.put("zeppelin.spark.useHiveContext",
- new InterpreterProperty("zeppelin.spark.useHiveContext", false, InterpreterPropertyType.checkbox));
+ new InterpreterProperty("zeppelin.spark.useHiveContext", false, InterpreterPropertyWidget.checkbox));
// set spark home for pyspark
sparkProperties.put("spark.home",
- new InterpreterProperty("spark.home", getSparkHome(), InterpreterPropertyType.text));
+ new InterpreterProperty("spark.home", getSparkHome(), InterpreterPropertyWidget.text));
sparkIntpSetting.setProperties(sparkProperties);
pySpark = true;
@@ -223,18 +223,18 @@ public abstract class AbstractTestRestApi {
if (sparkHome != null) {
if (System.getenv("SPARK_MASTER") != null) {
sparkProperties.put("master",
- new InterpreterProperty("master", System.getenv("SPARK_MASTER"), InterpreterPropertyType.text));
+ new InterpreterProperty("master", System.getenv("SPARK_MASTER"), InterpreterPropertyWidget.text));
} else {
sparkProperties.put("master",
- new InterpreterProperty("master", "local[2]", InterpreterPropertyType.text));
+ new InterpreterProperty("master", "local[2]", InterpreterPropertyWidget.text));
}
sparkProperties.put("spark.cores.max",
- new InterpreterProperty("spark.cores.max", "2", InterpreterPropertyType.text));
+ new InterpreterProperty("spark.cores.max", "2", InterpreterPropertyWidget.text));
// set spark home for pyspark
sparkProperties.put("spark.home",
- new InterpreterProperty("spark.home", sparkHome, InterpreterPropertyType.text));
+ new InterpreterProperty("spark.home", sparkHome, InterpreterPropertyWidget.text));
sparkProperties.put("zeppelin.spark.useHiveContext",
- new InterpreterProperty("zeppelin.spark.useHiveContext", false, InterpreterPropertyType.checkbox));
+ new InterpreterProperty("zeppelin.spark.useHiveContext", false, InterpreterPropertyWidget.checkbox));
pySpark = true;
sparkR = true;
}
diff --git a/zeppelin-web/src/app/interpreter/interpreter-create/interpreter-create.html b/zeppelin-web/src/app/interpreter/interpreter-create/interpreter-create.html
index 41b8e72f49..9ab9ca5717 100644
--- a/zeppelin-web/src/app/interpreter/interpreter-create/interpreter-create.html
+++ b/zeppelin-web/src/app/interpreter/interpreter-create/interpreter-create.html
@@ -277,8 +277,11 @@ limitations under the License.
| {{key}} |
-
+ |
+
+
+
|
@@ -296,14 +299,17 @@ limitations under the License.
-
+ |
+
+
+
|
- |
diff --git a/zeppelin-server/src/main/java/org/apache/zeppelin/rest/InterpreterRestApi.java b/zeppelin-server/src/main/java/org/apache/zeppelin/rest/InterpreterRestApi.java
index 46c363e0eb..25e8581245 100644
--- a/zeppelin-server/src/main/java/org/apache/zeppelin/rest/InterpreterRestApi.java
+++ b/zeppelin-server/src/main/java/org/apache/zeppelin/rest/InterpreterRestApi.java
@@ -21,7 +21,6 @@ import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
-import java.util.Properties;
import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.DELETE;
@@ -37,7 +36,7 @@ import javax.ws.rs.core.Response.Status;
import com.google.gson.Gson;
import org.apache.commons.lang.exception.ExceptionUtils;
-import org.apache.zeppelin.interpreter.InterpreterPropertyType;
+import org.apache.zeppelin.interpreter.InterpreterPropertyWidget;
import org.apache.zeppelin.interpreter.InterpreterSettingManager;
import org.apache.zeppelin.rest.message.RestartInterpreterRequest;
import org.apache.zeppelin.utils.SecurityUtils;
@@ -296,11 +295,11 @@ public class InterpreterRestApi {
}
/**
* Get available types for property
*/
@GET
- @Path("property/types")
- public Response listInterpreterPropertyTypes() {
- return new JsonResponse<>(Status.OK, InterpreterPropertyType.values()).build();
+ @Path("property/widgets")
+ public Response listInterpreterPropertyWidgets() {
+ return new JsonResponse<>(Status.OK, InterpreterPropertyWidget.values()).build();
}
}
@@ -296,11 +295,11 @@ public class InterpreterRestApi {
}
/**
- * Get available types for property
+ * Get available widgets for property
*/